import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-iam-floyd", "0.374.0", __name__[0:-6], "cdk-iam-floyd@0.374.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
